.. _ce_aucu_tutorial:

Au-Cu alloy example
===================

Constructing your CE model
--------------------------

.. toctree::

  ./aucu_concentration
  ./linsys_examples
  ./aucu_setting
  ./aucu_initial_pool
  ./aucu_run_calculations
  ./aucu_evaluate
  ./aucu_probe_gs

After constructing the CE model
-------------------------------

.. toctree::

  ./montecarlo_sampling
